@@ -9,10 +9,14 @@ use Perl::Tidy;
 use Data::Dumper;
 use Module::Starter;
 $Data::Dumper::Deparse = 1;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 our %CLASS;
 our $SUB_INDEX = 1;
 
+sub new {
+	return ref $_[0] ? $_[0] : bless {}, $_[0];
+}
+
 sub dist {
 	$CLASS{DIST} = $_[1];
 	return ref $_[0] ? $_[0] : bless {}, $_[0];
@@ -395,7 +399,7 @@ Module::Generate - Assisting with module generation.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -411,7 +415,7 @@ Version 0.06
 			->abstract('Over my head.')
 			->our('$type')
 			->begin(sub {
-				$one = 'boeing';
+				$type = 'boeing';
 			})
 			->sub('new')
 				->code(sub { return bless {}, $_[0] })
